@@ -13,35 +13,52 @@ PACKAGE_PATH = "eveuniverse.management.commands"
 
 @patch(PACKAGE_PATH + ".eveuniverse_load_data.is_esi_online", lambda: True)
 @patch(PACKAGE_PATH + ".eveuniverse_load_data.get_input")
-class TestLoadCommand(NoSocketsTestCase):
+class TestLoadDataCommand(NoSocketsTestCase):
     @patch(PACKAGE_PATH + ".eveuniverse_load_data.load_map")
     def test_load_data_map(self, mock_load_map, mock_get_input):
+        # given
         mock_get_input.return_value = "y"
-
+        # when
         call_command("eveuniverse_load_data", "map", stdout=StringIO())
+        # then
         self.assertTrue(mock_load_map.delay.called)
 
     @patch(PACKAGE_PATH + ".eveuniverse_load_data.load_ship_types")
     def test_load_data_ship_types(self, mock_load_ship_types, mock_get_input):
+        # given
         mock_get_input.return_value = "y"
-
+        # when
         call_command("eveuniverse_load_data", "ships", stdout=StringIO())
+        # then
         self.assertTrue(mock_load_ship_types.delay.called)
 
     @patch(PACKAGE_PATH + ".eveuniverse_load_data.load_structure_types")
     def test_load_data_structure_types(self, mock_load_structure_types, mock_get_input):
+        # given
         mock_get_input.return_value = "y"
-
+        # when
         call_command("eveuniverse_load_data", "structures", stdout=StringIO())
+        # then
         self.assertTrue(mock_load_structure_types.delay.called)
 
     @patch(PACKAGE_PATH + ".eveuniverse_load_data.load_map")
     def test_can_abort(self, mock_load_map, mock_get_input):
+        # given
         mock_get_input.return_value = "n"
-
+        # when
         call_command("eveuniverse_load_data", "map", stdout=StringIO())
+        # then
         self.assertFalse(mock_load_map.delay.called)
 
+    @patch(PACKAGE_PATH + ".eveuniverse_load_data.load_map")
+    def test_should_skip_confirmation_question(self, mock_load_map, mock_get_input):
+        # given
+        mock_get_input.side_effect = RuntimeError
+        # when
+        call_command("eveuniverse_load_data", "map", "--noinput", stdout=StringIO())
+        # then
+        self.assertTrue(mock_load_map.delay.called)
+
 
 @override_settings(CELERY_ALWAYS_EAGER=True, CELERY_EAGER_PROPAGATES_EXCEPTIONS=True)
 @patch("eveuniverse.managers.esi")
